.. _all-salt.thorium:

===============
thorium modules
===============

.. currentmodule:: salt.thorium

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    calc
    check
    file
    key
    local
    reg
    runner
    status
    timer
    wheel
